=========
astromath
=========


.. image:: https://img.shields.io/pypi/v/astromath.svg
        :target: https://pypi.python.org/pypi/astromath

.. image:: https://img.shields.io/travis/qxlsz/astromath.svg
        :target: https://travis-ci.com/qxlsz/astromath

.. image:: https://readthedocs.org/projects/astromath/badge/?version=latest
        :target: https://astromath.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/qxlsz/astromath/shield.svg
     :target: https://pyup.io/repos/github/qxlsz/astromath/
     :alt: Updates



Library for mathematical astronomy


* Free software: MIT license
* Documentation: https://astromath.readthedocs.io.
